@@ -1,5 +1,5 @@
 pub use code::Code;
-pub use lint::{Error as LintError, Lint};
+pub use lint::{Error as LintError, Lint, CONFIG_KEY_PREFIX};
 pub use lints::{Error, Lints};
 pub use problem::Problem;
 
